@@ -1,8 +1,9 @@
 from easypost.resource import (
     AllResource,
     CreateResource,
+    NextPageResource,
 )
 
 
-class Insurance(AllResource, CreateResource):
+class Insurance(AllResource, CreateResource, NextPageResource):
     pass
