@@ -1,8 +1,9 @@
 from easypost.resource import (
     AllResource,
     CreateResource,
+    NextPageResource,
 )
 
 
-class Refund(CreateResource, AllResource):
+class Refund(CreateResource, AllResource, NextPageResource):
     pass
