@@ -1,6 +1,7 @@
 import re
 from typing import (
     Any,
+    Dict,
     List,
     Optional,
 )
@@ -65,6 +66,39 @@ class AllResource(Resource):
         return convert_to_easypost_object(response=response, api_key=api_key)
 
 
+class NextPageResource(Resource):
+    @classmethod
+    def get_next_page(
+        cls,
+        collection: Dict[str, Any],
+        page_size: int,
+        api_key: Optional[str] = None,
+        optional_params: Optional[Dict[str, Any]] = None,
+    ) -> List[Any]:
+        """Retrieve next page of a specific collection."""
+        requestor = Requestor(local_api_key=api_key)
+        url = cls.class_url()
+        collection_array = collection.get(url[1:])
+
+        if collection_array is None or len(collection_array) == 0 or not collection.get("has_more"):
+            raise Error(message="There are no more pages to retrieve.")
+
+        params = {
+            "before_id": collection_array[-1].id,
+            "page_size": page_size,
+        }
+
+        if optional_params:
+            params.update(optional_params)
+
+        response, api_key = requestor.request(method=RequestMethod.GET, url=url, params=params)
+        response_array: List[Any] = response.get(url[1:])  # type: ignore
+        if response is None or len(response_array) == 0 or not response.get("has_more"):
+            raise Error(message="There are no more pages to retrieve.")
+
+        return convert_to_easypost_object(response=response, api_key=api_key)
+
+
 class CreateResource(Resource):
     @classmethod
     def create(cls, api_key: Optional[str] = None, **params) -> Any:
