@@ -1,6 +1,7 @@
 import pytest
 
 import easypost
+from easypost.error import Error
 
 
 @pytest.mark.vcr()
@@ -30,6 +31,21 @@ def test_refund_all(page_size):
     assert all(isinstance(refund, easypost.Refund) for refund in refunds_array)
 
 
+@pytest.mark.vcr()
+def test_refund_get_next_page(page_size):
+    try:
+        refunds = easypost.Refund.all(page_size=page_size)
+        next_page = easypost.Refund.get_next_page(collection=refunds, page_size=page_size)
+
+        first_id_of_first_page = refunds["refunds"][0].id
+        first_id_of_second_page = next_page["refunds"][0].id
+
+        assert first_id_of_first_page != first_id_of_second_page
+    except Error as e:
+        if e.message != "There are no more pages to retrieve.":
+            raise Error(message="Test failed intentionally.")
+
+
 @pytest.mark.vcr()
 def test_refund_retrieve(page_size):
     refunds = easypost.Refund.all(page_size=page_size)
