@@ -1,6 +1,7 @@
 import pytest
 
 import easypost
+from easypost.error import Error
 
 
 @pytest.mark.vcr()
@@ -34,3 +35,18 @@ def test_scanform_all(page_size):
     assert len(scanforms_array) <= page_size
     assert scanforms["has_more"] is not None
     assert all(isinstance(scanform, easypost.ScanForm) for scanform in scanforms_array)
+
+
+@pytest.mark.vcr()
+def test_scanform_get_next_page(page_size):
+    try:
+        scanforms = easypost.ScanForm.all(page_size=page_size)
+        next_page = easypost.ScanForm.get_next_page(collection=scanforms, page_size=page_size)
+
+        first_id_of_first_page = scanforms["scan_forms"][0].id
+        first_id_of_second_page = next_page["scan_forms"][0].id
+
+        assert first_id_of_first_page != first_id_of_second_page
+    except Error as e:
+        if e.message != "There are no more pages to retrieve.":
+            raise Error(message="Test failed intentionally.")
